@@ -23,7 +23,7 @@
 //! To be able to sort custom types, implement `RadixKey` as below.
 //!
 //!  * `LEVELS` should be set to the total number of bytes you will consider for each item being sorted
-//!  * `get_level` should return the corresponding bytes from the most significant byte to the least significant byte
+//!  * `get_level` should return the corresponding bytes from the least significant byte to the most significant byte
 //!
 //! Notes:
 //! * This allows you to implement radix keys that span multiple values, or to implement radix keys that only look at part of a value.
@@ -37,12 +37,7 @@
 //!
 //!     #[inline]
 //!     fn get_level(&self, level: usize) -> u8 {
-//!         let b = self.to_le_bytes();
-//!
-//!         match level {
-//!             0 => b[1],
-//!             _ => b[0],
-//!         }
+//!         self.to_le_bytes()[level]
 //!     }
 //! }
 //! ```
@@ -57,7 +52,7 @@
 //!
 //!     #[inline]
 //!     fn get_level(&self, level: usize) -> u8 {
-//!         (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
+//!         (self >> (level * 8)) as u8
 //!     }
 //! }
 //! ```
@@ -95,89 +90,35 @@
 //!
 //! Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.
 
-#[cfg(test)]
-mod tests;
-
-mod lsb_radix_sort;
-mod msb_ska_sort;
+mod director;
 mod radix_key;
 #[cfg(feature = "default-implementations")]
 mod radix_key_impl;
-mod scanning_radix_sort;
+
+#[cfg(not(any(test, feature = "bench")))]
+mod sorts;
+#[cfg(any(test, feature = "bench"))]
+pub mod sorts;
+
+#[cfg(not(any(test, feature = "bench")))]
 mod tuning_parameters;
+#[cfg(any(test, feature = "bench"))]
+pub mod tuning_parameters;
+
+#[cfg(not(any(test, feature = "bench")))]
 mod utils;
+#[cfg(any(test, feature = "bench"))]
+pub mod utils;
 
+#[cfg(feature = "bench")]
+pub mod bench_utils;
+
+#[cfg(any(test, feature = "bench"))]
+pub mod test_utils;
+
+mod radix_sort;
+mod sort_manager;
+
+// Public exports
 pub use radix_key::RadixKey;
-
-// Exposed for benchmarking
-#[cfg(any(test, feature = "bench"))]
-pub use crate::msb_ska_sort::msb_ska_sort;
-#[cfg(any(test, feature = "bench"))]
-pub use crate::tuning_parameters::TuningParameters;
-#[cfg(any(test, feature = "bench"))]
-pub use lsb_radix_sort::lsb_radix_sort_adapter;
-#[cfg(any(test, feature = "bench"))]
-pub use scanning_radix_sort::*;
-#[cfg(any(test, feature = "bench"))]
-pub use utils::*;
-
-#[cfg(not(any(test, feature = "bench")))]
-use crate::lsb_radix_sort::lsb_radix_sort_adapter;
-#[cfg(not(any(test, feature = "bench")))]
-use crate::scanning_radix_sort::scanning_radix_sort;
-#[cfg(not(any(test, feature = "bench")))]
-use crate::tuning_parameters::TuningParameters;
-
-fn radix_sort_bucket_start<T>(tuning: &TuningParameters, bucket: &mut [T])
-where
-    T: RadixKey + Sized + Send + Copy + Sync,
-{
-    if bucket.len() < 2 {
-        return;
-    }
-
-    let parallel_count = bucket.len() >= tuning.par_count_threshold;
-
-    if bucket.len() >= tuning.scanning_sort_threshold {
-        scanning_radix_sort(tuning, bucket, 0, parallel_count);
-    } else {
-        lsb_radix_sort_adapter(bucket, T::LEVELS - 1, 0, parallel_count);
-    }
-}
-
-fn radix_sort_inner<T>(bucket: &mut [T])
-where
-    T: RadixKey + Sized + Send + Copy + Sync,
-{
-    if T::LEVELS == 0 {
-        panic!("RadixKey must have at least 1 level");
-    }
-
-    let tuning = TuningParameters::new(T::LEVELS);
-
-    radix_sort_bucket_start(&tuning, bucket);
-}
-
-pub trait RadixSort {
-    /// radix_sort_unstable runs the actual radix sort based upon the `rdst::RadixKey` implementation
-    /// of `T` in your `Vec<T>` or `[T]`.
-    fn radix_sort_unstable(&mut self);
-}
-
-impl<T> RadixSort for Vec<T>
-where
-    T: RadixKey + Sized + Send + Copy + Sync,
-{
-    fn radix_sort_unstable(&mut self) {
-        radix_sort_inner(self);
-    }
-}
-
-impl<T> RadixSort for [T]
-where
-    T: RadixKey + Sized + Send + Copy + Sync,
-{
-    fn radix_sort_unstable(&mut self) {
-        radix_sort_inner(self);
-    }
-}
+pub use radix_sort::RadixSort;
