@@ -1,7 +1,8 @@
 use std::cmp::min;
 
 pub struct TuningParameters {
-    pub comparison_sort_threshold: usize,
+    pub cpus: usize,
+    pub recombinating_sort_threshold: usize,
     pub scanning_sort_threshold: usize,
     pub ska_sort_threshold: usize,
     pub par_count_threshold: usize,
@@ -11,7 +12,8 @@ pub struct TuningParameters {
 impl TuningParameters {
     pub fn new(levels: usize) -> Self {
         Self {
-            comparison_sort_threshold: 32,
+            cpus: num_cpus::get(),
+            recombinating_sort_threshold: Self::recombinating_sort_threshold(),
             scanning_sort_threshold: Self::scanning_sort_threshold(),
             ska_sort_threshold: Self::ska_sort_threshold(levels),
             par_count_threshold: Self::par_count_threshold(),
@@ -19,8 +21,12 @@ impl TuningParameters {
         }
     }
 
+    fn recombinating_sort_threshold() -> usize {
+        150_000
+    }
+
     fn scanning_sort_threshold() -> usize {
-        200_000
+        10_000_000
     }
 
     fn ska_sort_threshold(levels: usize) -> usize {
@@ -32,13 +38,13 @@ impl TuningParameters {
     }
 
     fn par_count_threshold() -> usize {
-        220_000
+        400_000
     }
 
     fn scanner_read_size() -> usize {
         let cpus = num_cpus::get();
         let scaling_factor = min(1, (cpus as f32).log2().ceil() as isize) as usize;
 
-        65536 / scaling_factor
+        32768 / scaling_factor
     }
 }
